<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked RecentChanges class.
 *
 * $Horde: wicked/lib/Page/RecentChanges.php,v 1.18 2004/10/21 17:27:05 jan Exp $
 *
 * @author  Tyler Colbert <tyler-hordeml@colberts.us>
 * @version $Revision: 1.18 $
 * @package Wicked
 */
class RecentChanges extends Page {

    /**
     * Display modes supported by this page.
     * @var array $supportedModes
     */
    var $supportedModes = array(
        WICKED_MODE_CONTENT => true,
        WICKED_MODE_DISPLAY => true);

    /**
     * Render this page in Content mode.
     *
     * @return string  The page content, or PEAR_Error.
     */
    function content()
    {
        global $wicked;

        $summaries = $wicked->getRecentChanges();

        $bydate = array();
        $changes = array();
        foreach ($summaries as $page) {
            $page = &new StandardPage($page);
            
            $createDate = $page->versionCreated();
            $tm = localtime($createDate, true);
            $createDate = mktime(0, 0, 0, $tm['tm_mon'], $tm['tm_mday'], 
                                 $tm['tm_year'], $tm['tm_isdst']);

            $version_url = Util::addParameter($page->pageUrl(), 'version',
                                              $page->version());
            $diff_url = Util::addParameter(Horde::applicationUrl('diff.php'),
                                           array('page' => $page->pageName(),
                                                 'v1' => '?',
                                                 'v2' => $page->version()));
            $diff_alt = sprintf(_("Show changes for %s"), $page->version());
            $diff_img = Horde::img('diff.png', $diff_alt);
            $pageInfo = array('author' => $page->author(),
                              'name' => $page->pageName(),
                              'url' => $page->pageUrl(),
                              'version' => $page->version(),
                              'version_url' => $version_url,
                              'version_alt' => sprintf(_("Show version %s"),
                                                       $page->version()),
                              'diff_url' => $diff_url,
                              'diff_alt' => $diff_alt,
                              'diff_img' => $diff_img,
                              'created' => $page->formatVersionCreated(),
                              'change_log' => $page->changeLog());
            $bydate[$createDate][$page->versionCreated()] = $pageInfo;
        }
        krsort($bydate);

        foreach ($bydate as $pageList) {
            krsort($pageList);
            $pageList = array_values($pageList);
            $changes[] = array('date' => $pageList[0]['created'],
                               'pages' => $pageList);
        }

        return $changes;
    }

    /**
     * Render this page in display or block mode.
     *
     * @return mixed  Returns true or PEAR_Error.
     */
    function displayContents($isBlock)
    {
        $changes = $this->content();
        if (is_a($changes, 'PEAR_Error')) {
            global $notification;
            $notification->push('Error retrieving histories: ' . $summaries->toString(), 'horde.error');
            return $changes;
        }

        require_once 'Horde/Template.php';
        $template = &new Horde_Template();
        $template->set('changes', $changes);

        return $template->fetch(WICKED_TEMPLATES . '/display/RecentChanges.html');
    }

    function pageName()
    {
        return _("RecentChanges");
    }

    function pageUrl($linkpage = 'display.php', $actionid = 'none')
    {
        $url = Horde::applicationUrl($linkpage);
        $url = Util::addParameter($url, 'page', $this->pageName());
        return Util::addParameter($url, 'actionID', $actionid);
    }

}
